Crate astarte_interfaces

Crate astarte_interfaces 

Astarte interfaces

Re-exports

pub use self::interface::datastream::individual::DatastreamIndividual;
pub use self::interface::datastream::object::DatastreamObject;
pub use self::interface::properties::Properties;
pub use self::interface::AggregationIndividual;
pub use self::interface::Interface;
pub use self::interface::Schema;
pub use self::mapping::datastream::individual::DatastreamIndividualMapping;
pub use self::mapping::datastream::object::DatastreamObjectMapping;
pub use self::mapping::endpoint::Endpoint;
pub use self::mapping::path::MappingPath;
pub use self::mapping::properties::PropertiesMapping;
pub use self::mapping::InterfaceMapping;

Modules

error
Errors generated by the interface module.
interface
Provides the functionalities to parse and validate an Astarte interface.
mapping
Mapping of an interface.
schema
Astarte Interface definition, this module contains the structs for the actual JSON representation definition of the Interface and mapping.