Module interface

Module interface 

Provides the functionalities to parse and validate an Astarte interface.

Re-exports

pub use crate::schema::Aggregation;
pub use crate::schema::DatabaseRetentionPolicy;
pub use crate::schema::InterfaceType;
pub use crate::schema::Ownership;

Modules

datastream
Interface for streams of non persistent data.
name
Name of an interface
properties
Interface for persistent, stateful, synchronized state with no concept of history or timestamp.
validation
Validate an interface and the version change between two interfaces.
version
Version of an Interface

Structs

Interface
Astarte interface implementation.

Enums

DatabaseRetention
Defines if data should be expired from the database after a given interval.
InterfaceTypeAggregation
Enum of all the types and aggregation of interfaces
Retention
Defines the retention of a data stream.

Constants

MAX_INTERFACE_MAPPINGS
Maximum number of mappings an interface can have

Traits

AggregationIndividual
Access information of an interface with Aggregation individual.
Schema
Access to the information of an interface.