pub enum ObjectError {
Mapping {
ctx: &'static str,
endpoint: String,
},
Endpoint {
endpoint: String,
},
}Expand description
Error when parsing a DatastreamObject
Variants
Mapping
Object has a different value for the specified mapping
Fields
Endpoint
Mapping endpoint differs from others
It needs to have up to the latest level equal to the others endpoints.