pub struct DatastreamObject { /* private fields */ }Expand description
Interface of type datastream object.
For this interface all the mappings have the same prefix and configurations.
Implementations
Sourceimpl DatastreamObject
impl DatastreamObject
Sourcepub fn reliability(&self) -> Reliability
pub fn reliability(&self) -> Reliability
Return the reliability for the object.
Sourcepub fn explicit_timestamp(&self) -> bool
pub fn explicit_timestamp(&self) -> bool
Return true if the object requires an explicit timestamp.
Otherwise the reception timestamp is used.
Sourcepub fn is_object_path(&self, path: &MappingPath<'_>) -> bool
pub fn is_object_path(&self, path: &MappingPath<'_>) -> bool
Check if the path if the correct one for this object interface.
Sourcepub fn mapping(&self, path: &str) -> Option<&DatastreamObjectMapping>
pub fn mapping(&self, path: &str) -> Option<&DatastreamObjectMapping>
Get a mapping for in the object for the given field.
The field is the last level of an endpoint.