DatabaseRetention

Enum DatabaseRetention 

pub enum DatabaseRetention {
    NoTtl,
    UseTtl {
        ttl: Duration,
    },
}
Defines if data should be expired from the database after a given interval.

See Database Retention Policy for more information.

Variants



NoTtl

Data will never expire.



UseTtl

Data will live for the ttl.

Fields

ttl: Duration

Time to live int the database.

Implementations

Source

impl DatabaseRetention

pub fn is_no_ttl(&self) -> bool

Returns true if the database retention is NoTtl.

pub fn is_use_ttl(&self) -> bool

Returns true if the database retention is UseTtl.

pub fn as_ttl(&self) -> Option<&Duration>

Returns the duration of the ttl if the policy is UseTtl

pub fn as_ttl_secs(&self) -> Option<i64>

Returns the duration of the ttl if the policy is UseTtl