pub enum InterfaceTypeAggregation {
DatastreamIndividual(DatastreamIndividual),
DatastreamObject(DatastreamObject),
Properties(Properties),
}Expand description
Enum of all the types and aggregation of interfaces
This is not a direct representation of only the mapping to permit extensibility of specific properties present only in some aggregations.
Variants
DatastreamIndividual(DatastreamIndividual)
Interface with type datastream and aggregations individual.
DatastreamObject(DatastreamObject)
Interface with type datastream and aggregations object.
Properties(Properties)
A property interface.