Retention

Enum Retention 

pub enum Retention {
    Discard,
    Volatile {
        expiry: Option<Duration>,
    },
    Stored {
        expiry: Option<Duration>,
    },
}
Defines the retention of a data stream.

Describes what to do with the sent data if the transport is incapable of delivering it.

See Retention for more information.

Variants



Discard

Data is discarded.



Volatile

Data is kept in a cache in memory.

Fields

expiry: Option<Duration>

Duration for the data to expire.

If it’s None it will never expire.



Stored

Data is kept on disk.

Fields

expiry: Option<Duration>

Duration for the data to expire.

If it’s None it will never expire.

Implementations

Source

impl Retention

pub const fn is_stored(&self) -> bool

Returns true if the retention is Stored.

pub const fn as_expiry(&self) -> Option<&Duration>

Returns the expiry for the retention.

For the Discard will always return None, while for Volatile or Stored returns the inner expiry only if set.

pub fn as_expiry_seconds(&self) -> Option<i64>

Returns the expiry for the retention in seconds.

For the Discard will always return None, while for Volatile or Stored returns the inner expiry only if set.

pub const fn is_volatile(&self) -> bool

Returns true if the retention is Volatile.

pub const fn is_discard(&self) -> bool

Returns true if the retention is Discard.