pub struct Interface { /* private fields */ }Expand description
Astarte interface implementation.
Should be used only through its conversion methods, not instantiated directly.
Implementations
Sourceimpl Interface
impl Interface
Sourcepub fn inner(&self) -> &InterfaceTypeAggregation
pub fn inner(&self) -> &InterfaceTypeAggregation
Returns the inner enum of the InterfaceTypeAggregation
Sourcepub fn interface_name(&self) -> &str
pub fn interface_name(&self) -> &str
Returns the interface name.
Sourcepub fn version(&self) -> InterfaceVersion
pub fn version(&self) -> InterfaceVersion
Returns the interface version.
Sourcepub fn version_major(&self) -> i32
pub fn version_major(&self) -> i32
Returns the interface major version.
Sourcepub fn version_minor(&self) -> i32
pub fn version_minor(&self) -> i32
Returns the interface minor version.
Sourcepub fn interface_type(&self) -> InterfaceType
pub fn interface_type(&self) -> InterfaceType
Returns the interface type.
Sourcepub fn aggregation(&self) -> Aggregation
pub fn aggregation(&self) -> Aggregation
Returns the interface aggregation.
Sourcepub fn validate_with(&self, prev: &Self) -> Result<&Self, Error>
pub fn validate_with(&self, prev: &Self) -> Result<&Self, Error>
Validate an interface given the previous version prev.
It will check whether:
- Both the versions are valid
- The name of the interface is the same
- The new version is a valid successor of the previous version.
Sourcepub fn as_datastream_individual(&self) -> Option<&DatastreamIndividual>
pub fn as_datastream_individual(&self) -> Option<&DatastreamIndividual>
Return a reference to a DatastreamIndividual.
Sourcepub fn as_datastream_object(&self) -> Option<&DatastreamObject>
pub fn as_datastream_object(&self) -> Option<&DatastreamObject>
Return a reference to a DatastreamObject.
Sourcepub fn as_properties(&self) -> Option<&Properties>
pub fn as_properties(&self) -> Option<&Properties>
Return a reference to a Properties.
Sourcepub fn is_datastream_individual(&self) -> bool
pub fn is_datastream_individual(&self) -> bool
Returns true if the interface type is DatastreamIndividual.
Sourcepub fn is_datastream_object(&self) -> bool
pub fn is_datastream_object(&self) -> bool
Returns true if the interface type is DatastreamObject.
Sourcepub fn is_properties(&self) -> bool
pub fn is_properties(&self) -> bool
Returns true if the interface type is Properties.