Validate an interface and the version change between two interfaces.
Structs
- Version
Change - A change in version of an interface.
Enums
- Version
Change Error - Error for changing the version of an interface.
Validate an interface and the version change between two interfaces.