DatastreamObjectMapping

Struct DatastreamObjectMapping 

pub struct DatastreamObjectMapping { /* private fields */ }
Shared struct for a mapping for all interface types.

Implementations

Source

impl DatastreamObjectMapping

pub fn required(&self) -> bool

Flag to specify if the mapping is required.

Object Aggregates mappings are optional by default, with this flag you can mark it as required.

pub fn cmp_object_field(&self, path: &str) -> Ordering

Compares the object field with the mapping endpoint.

Returns the ordering of the mappings.

pub fn eq_object_field(&self, path: &str) -> bool

Compares the object field with the mapping endpoint.

Returns true if the last level is equal to the object field.