pub enum MappingError {
Empty,
TooMany(usize),
Duplicated {
endpoint: String,
},
Endpoint(EndpointError),
TooShortForObject(String),
Schema(SchemaError),
}Expand description
Error returned by the interface mappings.
Variants
Empty
An interface must have at least one mapping.
TooMany(usize)
An interface can have at max MAX_INTERFACE_MAPPINGS mappings.
Duplicated
The endpoint of all the mappings of an interface must have an unique endpoint.
This includes the parameters.
Endpoint(EndpointError)
Couldn’t parse the mapping’s endpoint
TooShortForObject(String)
The object interface endpoints should have at least 2 levels.
Schema(SchemaError)
The interface schema is invalid for mapping.