pub enum Reliability {
Unreliable,
Guaranteed,
Unique,
}Expand description
Reliability of a data stream.
Defines whether the sent data should be considered delivered.
Properties have always a unique reliability.
See Reliability for more information.
Variants
Unreliable
If the transport sends the data
Guaranteed
When we know the data has been received at least once.
Unique
When we know the data has been received exactly once.
Implementations
Sourceimpl Reliability
impl Reliability
Sourcepub fn is_unreliable(&self) -> bool
pub fn is_unreliable(&self) -> bool
Returns true if the reliability is Unreliable.
Sourcepub fn is_guaranteed(&self) -> bool
pub fn is_guaranteed(&self) -> bool
Returns true if the reliability is Guaranteed.