InterfaceJson

Struct InterfaceJson 

pub struct InterfaceJson<T>
where T: AsRef<str>,
{ /* private fields */ }
The structure is a direct mapping of the JSON schema, they are then transformed in our internal representation of Interface when de-serializing using TryFrom.

The fields of the JSON can either be:

  • Required: the field is the value it represents, it cannot be omitted.
  • Optional with default: the field is optional, but it is value it represents (not wrapped in Option). It will not be serialized if the value is the default one.
  • Optional: the field is optional, it is wrapped in Option. It will not be serialized if the value is None.

Implementations

Source

impl<T> InterfaceJson<T>
where T: AsRef<str>,

pub fn interface_name(&self) -> &str

The name of the interface.

This has to be an unique, alphanumeric reverse internet domain name, shorter than 128 characters.

pub fn version_major(&self) -> i32

The Major version qualifier for this interface.

Interfaces with the same id and different version_major number are deemed incompatible. It is then acceptable to redefine any property of the interface when changing the major version number.

It must be a positive number.

pub fn version_minor(&self) -> i32

The Minor version qualifier for this interface.

Interfaces with the same id and major version number and different version_minor number are deemed compatible between each other. When changing the minor number, it is then only possible to insert further mappings. Any other modification might lead to incompatibilities and undefined behavior.

It must be a positive number.

pub fn interface_type(&self) -> InterfaceType

Identifies the type of this Interface.

Currently two types are supported: datastream and properties. Datastream should be used when dealing with streams of non-persistent data, where a single path receives updates and there’s no concept of state. Properties, instead, are meant to be an actual state and as such they have only a change history, and are retained.

pub fn ownership(&self) -> Ownership

Identifies the direction of the interface.

Interfaces are meant to be unidirectional, and this property defines who’s sending or receiving data. device means the device/gateway is sending data to Astarte, consumer means the device/gateway is receiving data from Astarte. Bidirectional mode is not supported, you should instantiate another interface for that.

pub fn aggregation(&self) -> Option<Aggregation>

Identifies the aggregation of the mappings of the interface.

Individual means every mapping changes state or streams data independently, whereas an object aggregation treats the interface as an object, making all the mappings changes interdependent. Choosing the right aggregation might drastically improve performances.

pub fn description(&self) -> Option<&T>

An optional description of the interface.

pub fn doc(&self) -> Option<&T>

A string containing documentation that will be injected in the generated client code.

pub fn mappings(&self) -> &[Mapping<T>]

Mappings define the endpoint of the interface, where actual data is stored/streamed.

They are defined as relative URLs (e.g. /my/path) and can be parametrized (e.g.: /%{myparam}/path). A valid interface must have no mappings clash, which means that every mapping must resolve to a unique path or collection of paths (including parametrization). Every mapping acquires type, quality and aggregation of the interface.