Mapping

Struct Mapping 

pub struct Mapping<T>
where T: AsRef<str>,
{ /* private fields */ }
Mapping of an Interface.

It includes all the fields available for a mapping, but it it is validated when built with the TryFrom. It uniforms the different types of mappings like DatastreamIndividualMapping, DatastreamObjectMapping mappings and PropertiesMapping in a single struct.

Since it’s a 1:1 representation of the JSON it is used for serialization and deserialization, and then is converted to the internal representation of the mapping with the TryFrom and From traits of the Interface’s mappings. You can find the specification here Mapping Schema - Astarte

Implementations

Source

impl<T> Mapping<T>
where T: AsRef<str>,

pub fn endpoint(&self) -> &str

Path of the mapping.

It can be parametrized (e.g. /foo/%{path}/baz).

pub fn mapping_type(&self) -> MappingType

Defines the type of the mapping.

This represent the data that will be published on the mapping.

pub fn reliability(&self) -> Option<Reliability>

Defines when to consider the data delivered.

Useful only with datastream. Defines whether the sent data should be considered delivered when the transport successfully sends the data (unreliable), when we know that the data has been received at least once (guaranteed) or when we know that the data has been received exactly once (unique). Unreliable by default. When using reliable data, consider you might incur in additional resource usage on both the transport and the device’s end.

pub fn explicit_timestamp(&self) -> Option<bool>

Allow to set a custom timestamp.

Otherwise a timestamp is added when the message is received. If true explicit timestamp will also be used for sorting. This feature is only supported on datastreams.

pub fn retention(&self) -> Option<Retention>

Retention of the data when not deliverable.

Useful only with datastream. Defines whether the sent data should be discarded if the transport is temporarily uncapable of delivering it (discard) or should be kept in a cache in memory (volatile) or on disk (stored), and guaranteed to be delivered in the timeframe defined by the expiry.

pub fn expiry(&self) -> Option<i64>

Expiry for the retain data.

Useful when retention is stored. Defines after how many seconds a specific data entry should be kept before giving up and erasing it from the persistent cache. A value <= 0 means the persistent cache never expires, and is the default.

pub fn database_retention_policy(&self) -> Option<DatabaseRetentionPolicy>

Retention policy for the database.

Useful only with datastream. Defines whether data should expire from the database after a given interval. Valid values are: no_ttl and use_ttl.

pub fn database_retention_ttl(&self) -> Option<i64>

Seconds to keep the data in the database.

Useful when database_retention_policy is “use_ttl”. Defines how many seconds a specific data entry should be kept before erasing it from the database.

pub fn allow_unset(&self) -> Option<bool>

Allows the property to be unset.

Used only with properties.

pub fn required(&self) -> Option<bool>

Marks the mapping as required.

Used only with object datastream.

pub fn description(&self) -> Option<&T>

An optional description of the mapping.

pub fn doc(&self) -> Option<&T>

A string containing documentation that will be injected in the generated client code.

pub fn expiry_as_duration(&self) -> Result<Option<Duration>, SchemaError>

Expiry of the data stream.

If it’s None the stream will never expire.

pub fn retention_with_expiry(&self) -> Result<InterfaceRetention, SchemaError>

Retention of the data stream.

See the Retention documentation for more information.

pub fn database_retention_ttl_as_duration( &self, ) -> Result<Option<Duration>, SchemaError>

Database retention ttl of the data stream.

If it’s None the stream will never expire.

pub fn database_retention_with_ttl( &self, ) -> Result<InterfaceDatabaseRetention, SchemaError>

Returns the database retention of the data stream.

See the DatabaseRetention for more information.