Provides the functionalities to parse and validate an Astarte interface.
Re-exports
pub use crate::schema::Aggregation;pub use crate::schema::DatabaseRetentionPolicy;pub use crate::schema::InterfaceType;pub use crate::schema::Ownership;
Modules
- datastream
- Interface for streams of non persistent data.
- name
- Name of an interface
- properties
- Interface for persistent, stateful, synchronized state with no concept of history or timestamp.
- validation
- Validate an interface and the version change between two interfaces.
- version
- Version of an Interface
Structs
- Interface
- Astarte interface implementation.
Enums
- Database
Retention - Defines if data should be expired from the database after a given interval.
- Interface
Type Aggregation - Enum of all the types and aggregation of interfaces
- Retention
- Defines the retention of a data stream.
Constants
- MAX_
INTERFACE_ MAPPINGS - Maximum number of mappings an interface can have
Traits
- Aggregation
Individual - Access information of an interface with
Aggregationindividual. - Schema
- Access to the information of an interface.