Interface

Struct Interface 

pub struct Interface { /* private fields */ }
Astarte interface implementation.

Should be used only through its conversion methods, not instantiated directly.

Implementations

Source

impl Interface

pub fn inner(&self) -> &InterfaceTypeAggregation

Returns the inner enum of the InterfaceTypeAggregation

pub fn interface_name(&self) -> &str

Returns the interface name.

pub fn version(&self) -> InterfaceVersion

Returns the interface version.

pub fn version_major(&self) -> i32

Returns the interface major version.

pub fn version_minor(&self) -> i32

Returns the interface minor version.

pub fn interface_type(&self) -> InterfaceType

Returns the interface type.

pub fn ownership(&self) -> Ownership

Returns the interface ownership.

pub fn aggregation(&self) -> Aggregation

Returns the interface aggregation.

pub fn validate_with(&self, prev: &Self) -> Result<&Self, Error>

Validate an interface given the previous version prev.

It will check whether:

  • Both the versions are valid
  • The name of the interface is the same
  • The new version is a valid successor of the previous version.
pub fn as_datastream_individual(&self) -> Option<&DatastreamIndividual>

Return a reference to a DatastreamIndividual.

pub fn as_datastream_object(&self) -> Option<&DatastreamObject>

Return a reference to a DatastreamObject.

pub fn as_properties(&self) -> Option<&Properties>

Return a reference to a Properties.

pub fn is_datastream_individual(&self) -> bool

Returns true if the interface type is DatastreamIndividual.

pub fn is_datastream_object(&self) -> bool

Returns true if the interface type is DatastreamObject.

pub fn is_properties(&self) -> bool

Returns true if the interface type is Properties.