pub enum DatabaseRetentionPolicy {
NoTtl,
UseTtl,
}Expand description
Defines whether data should expire from the database after a given interval.
See Database Retention Policy for more information.
Variants
NoTtl
The data will never expiry.
UseTtl
The data will expire after the ttl.
The field database_retention_ttl will be used to
determine how many seconds the data is kept in the database.