Reliability

Enum Reliability 

pub enum Reliability {
    Unreliable,
    Guaranteed,
    Unique,
}
Reliability of a data stream.

Defines whether the sent data should be considered delivered.

Properties have always a unique reliability.

See Reliability for more information.

Variants



Unreliable

If the transport sends the data



Guaranteed

When we know the data has been received at least once.



Unique

When we know the data has been received exactly once.

Implementations

Source

impl Reliability

pub fn is_unreliable(&self) -> bool

Returns true if the reliability is Unreliable.

pub fn is_guaranteed(&self) -> bool

Returns true if the reliability is Guaranteed.

pub fn is_unique(&self) -> bool

Returns true if the reliability is Unique.